(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[2645,3930],{83930:(e,r,t)=>{"use strict";t.r(r),t.d(r,{default:()=>a});var n=t(60977),s=t(76355),u=t(2968);const a=[{id:"@jupyterlab/user-extension:user",autoStart:!0,provides:s.ICurrentUser,activate:e=>new s.User},{id:"@jupyterlab/user-extension:userMenu",autoStart:!0,requires:[s.ICurrentUser],provides:s.IUserMenu,activate:(e,r)=>{const{commands:t}=e;return new s.UserMenu({commands:t,user:r})}},{id:"@jupyterlab/user-extension:userMenuBar",autoStart:!0,requires:[s.ICurrentUser,s.IUserMenu],activate:(e,r,t)=>{const{shell:a}=e;if("true"!==n.PageConfig.getOption("collaborative"))return;const o=new u.MenuBar({forceItemsPosition:{forceX:!1,forceY:!1},renderer:new s.RendererUserMenu(r)});o.id="jp-UserMenu",r.changed.connect((()=>o.update())),o.addMenu(t),a.add(o,"top",{rank:1e3})}}]}}]);