(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[9434,5060],{79434:(e,r,t)=>{"use strict";t.r(r),t.d(r,{default:()=>c});var i=t(60977),n=t(69835),o=t(76355),s=t(79988);const c=[{id:"@jupyterlab/docprovider-extension:plugin",requires:[o.ICurrentUser],provides:n.IDocumentProviderFactory,activate:(e,r)=>{const t=s.ServerConnection.makeSettings(),o=i.URLExt.join(t.wsUrl,"api/yjs"),c="true"==i.PageConfig.getOption("collaborative");return e=>c?new n.WebSocketProviderWithLocks(Object.assign(Object.assign({},e),{url:o,user:r})):new n.ProviderMock}}]}}]);