(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[6720],{66541:(e,t,o)=>{"use strict";o.r(t),o.d(t,{default:()=>d});var n=o(30603),a=o(31465),r=o(17134),l=o(43821),s=o(60699),i=o(2968);const d=[{id:"@retrolab/tree-extension:buttons",requires:[a.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:a}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-notebook";a.addCommand(i,{label:l.__("New Notebook"),icon:s.notebookIcon,execute:()=>a.execute("notebook:create-new")});const d=new n.CommandToolbarButton({commands:a,id:i}),c=new n.CommandToolbarButton({commands:a,id:"filebrowser:create-new-file"});r.toolbar.insertItem(0,"new-notebook",d),r.toolbar.insertItem(1,"new-file",c)}},{id:"@retrolab/tree-extension:new-console",requires:[a.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:a}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-console";a.addCommand(i,{label:l.__("New Console"),icon:s.consoleIcon,execute:()=>a.execute("console:create")});const d=new n.CommandToolbarButton({commands:a,id:i});r.toolbar.insertItem(2,"new-console",d)}},{id:"@retrolab/tree-extension:new-terminal",requires:[a.IFileBrowserFactory,l.ITranslator],autoStart:!0,activate:(e,t,o)=>{const{commands:a}=e,r=t.defaultBrowser,l=o.load("retrolab"),i="tree:new-terminal";a.addCommand(i,{label:l.__("New Terminal"),icon:s.terminalIcon,execute:()=>a.execute("terminal:create-new")});const d=new n.CommandToolbarButton({commands:a,id:i});r.toolbar.insertItem(3,"new-terminal",d)}},{id:"@retrolab/tree-extension:widget",requires:[a.IFileBrowserFactory,l.ITranslator],optional:[r.IRunningSessionManagers],autoStart:!0,activate:(e,t,o,n)=>{const a=new i.TabPanel({tabPlacement:"top",tabsMovable:!0});a.addClass("jp-TreePanel");const l=o.load("retrolab"),{defaultBrowser:d}=t;if(d.title.label=l.__("Files"),d.node.setAttribute("role","region"),d.node.setAttribute("aria-label",l.__("File Browser Section")),d.title.icon=s.folderIcon,a.addWidget(d),a.tabBar.addTab(d.title),n){const e=new r.RunningSessions(n,o);e.id="jp-running-sessions",e.title.label=l.__("Running"),e.title.icon=s.runningIcon,a.addWidget(e),a.tabBar.addTab(e.title)}e.shell.add(a,"main",{rank:100})}}]}}]);